#!/usr/bin/env python
# -*- coding: utf-8 -*-
# $Id: urls.py 11629 2019-06-11 17:44:34Z Lavender $
#
# Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
#
# Licensed under the Proprietary License, 
# you may not use this file except in compliance with the License. 
# You may obtain a copy of the License at our web site.
#
# See the License for the specific language governing permissions and 
# limitations under the License.
#
# $Author: Lavender $
# $Date: 2019-06-12 01:44:34 +0800 (週三, 12 六月 2019) $
# $Revision: 11629 $ 

from django.conf.urls import url

from . import views

#app_name = 'comment'

urlpatterns = [
    url(r'^comments/add$', views.CommentView.as_view(), name='addComment'),
    url(r'^comments/(?P<pk>\d+)/hide$', 
        views.CommentHideView.as_view(), name='hideComment'),
]
